@@ -20,6 +20,14 @@ pub struct DrawerState {
     layout: DrawerDrawingLayout,
 }
 
+#[derive(Debug, Clone, Copy)]
+pub enum Clicked {
+    Nothing,
+    Name(usize),
+    Value(usize),
+    Search,
+}
+
 #[derive(Debug, Clone, Copy)]
 pub enum EditionPos {
     Start,
@@ -144,7 +152,7 @@ impl DrawerState {
         &mut self,
         content_area: &Area,
     ) {
-        debug_assert!(content_area.height > 3);
+        debug_assert!(content_area.height > 4);
         self.layout.lines_area.left = 0;
         self.layout.lines_area.top = content_area.top + 3;
         let page_height = content_area.height - 3;
@@ -157,13 +165,18 @@ impl DrawerState {
         let lines_count = self.listed_entries_count();
         self.layout.content_height = 0;
         self.layout.value_heights_by_line.clear();
+        let max_value_height = if page_height > 7 {
+            page_height as usize - 5
+        } else {
+            page_height as usize - 2
+        };
         for l in 0..lines_count {
             let idx = self.listed_entry_idx(l).unwrap(); // SAFETY: we iter among valid lines
             let height = match &self.focus {
                 DrawerFocus::ValueEdit { input, line } if l == *line => {
                     // this line's value is edited, its height is given by the
                     // number of lines computed by the input
-                    input.content().line_count().min(page_height as usize - 5)
+                    input.content().line_count().min(max_value_height)
                 }
                 _ => {
                     let open = open_all_values || self.focus.is_value_selected(l);
@@ -175,7 +188,7 @@ impl DrawerState {
                             &self.drawer.content.entries[idx].value,
                             Some(value_width),
                         );
-                        text.lines.len().max(1).min(page_height as usize - 5)
+                        text.lines.len().min(max_value_height).max(1)
                     } else {
                         // this line's value is neither open nor selected, we display
                         // just the first line of the value (or a line of squares if
@@ -195,19 +208,31 @@ impl DrawerState {
         self.search.update(&self.drawer)
     }
 
-    pub fn clicked_line(&self, y: usize) -> Option<usize> {
-        let heights = self.layout.value_heights_by_line
-            .iter()
-            .enumerate()
-            .skip(self.scroll);
+    /// Tell what part of the drawer screen has been clicked
+    pub fn clicked(&self, x: u16, y: usize) -> Clicked {
+        let in_name_col = self.layout.is_in_name_column(x);
         let mut sum_heights = self.layout.lines_area.top as usize;
-        for (line, height) in heights {
-            sum_heights += height;
-            if sum_heights > y {
-                return Some(line);
+        if y < sum_heights {
+            if in_name_col && y > 1 {
+                return Clicked::Search;
+            }
+        } else {
+            let heights = self.layout.value_heights_by_line
+                .iter()
+                .enumerate()
+                .skip(self.scroll);
+            for (line, height) in heights {
+                sum_heights += height;
+                if sum_heights > y {
+                    if in_name_col {
+                        return Clicked::Name(line);
+                    } else {
+                        return Clicked::Value(line);
+                    }
+                }
             }
         }
-        None
+        Clicked::Nothing
     }
 
     pub fn scrollbar(&self) -> Option<(u16, u16)> {
@@ -349,6 +374,74 @@ impl DrawerState {
             _ => true,
         }
     }
+    pub fn apply_scroll_command(&mut self, scroll_command: ScrollCommand) {
+        let page_height = self.page_height();
+        let initial_scroll = self.scroll;
+        self.scroll = scroll_command.apply(
+            self.scroll,
+            self.layout.content_height,
+            page_height,
+        );
+        // if fix_scroll reverts to the previous position, it's because doing
+        // differently would hide the selection. In this case, and when the
+        // selection can be moved, we move it (and the fix_scroll happening
+        // at the start of the drawing will make it visible).
+        self.fix_scroll();
+        if self.scroll == initial_scroll {
+            let count = self.listed_entries_count();
+            let last_visible_line = self.last_visible_line();
+            if let Some(selection) = self.focus.selection_mut() {
+                match scroll_command {
+                    ScrollCommand::Top => {
+                        *selection = 0;
+                    }
+                    ScrollCommand::Bottom => {
+                        // safety: lines_count > 0 or we would not have any selection
+                        *selection = count - 1;
+                    }
+                    ScrollCommand::Lines(i) if i < 0 => {
+                        if *selection > 0 {
+                            *selection -= 1;
+                        }
+                    }
+                    ScrollCommand::Lines(i) if i > 0 => {
+                        if *selection + 1 < count {
+                            *selection += 1;
+                        }
+                    }
+                    ScrollCommand::Pages(-1) => {
+                        *selection = initial_scroll;
+                    }
+                    ScrollCommand::Pages(1) => {
+                        // safety: there's a last visible line or there would be not selection
+                        *selection = last_visible_line.unwrap();
+                    }
+                    _ => {
+                        warn!("unacounted scroll command: {:?}", scroll_command);
+                    }
+                }
+            }
+        }
+    }
+    pub fn last_visible_line(&self) -> Option<usize> {
+        let page_height = self.page_height();
+        let heights = self.layout.value_heights_by_line.iter()
+            .enumerate()
+            .skip(self.scroll);
+        let mut sum_heights = 0;
+        for (line, height) in heights {
+            sum_heights += height;
+            if sum_heights > page_height {
+                return Some(line);
+            }
+        }
+        let count = self.listed_entries_count();
+        if count > 0 {
+            Some(count - 1)
+        } else {
+            None
+        }
+    }
     /// Ensure the scroll is consistent with the size of content
     /// and terminal height, and that the selection is visible, if any.
     ///
@@ -429,13 +522,6 @@ impl DrawerState {
             false
         }
     }
-    pub fn apply_scroll_command(&mut self, scroll_command: ScrollCommand) {
-        self.scroll = scroll_command.apply(
-            self.scroll,
-            self.listed_entries_count(),
-            self.page_height(),
-        );
-    }
     pub fn close_input(&mut self, discard: bool) -> bool {
         if let DrawerFocus::NameEdit { line, input } = &self.focus {
             let line = *line;
