@@ -3,13 +3,14 @@ use {
         style::Color::*,
     },
     termimad::{
-        ansi, CompoundStyle, MadSkin,
+        ansi, gray, CompoundStyle, MadSkin,
     },
 };
 
 pub struct StatusSkin {
     pub hint: MadSkin,
     pub info: MadSkin,
+    pub task: MadSkin,
     pub error: MadSkin,
 }
 
@@ -22,9 +23,12 @@ impl Default for StatusSkin {
         info.paragraph.set_fg(AnsiValue(252));
         info.italic = CompoundStyle::with_fg(AnsiValue(222));
         info.set_bg(ansi(24));
+        let mut task = MadSkin::default();
+        task.paragraph.set_fg(gray(1));
+        task.set_bg(ansi(222));
         let mut error = MadSkin::default();
         error.paragraph.set_fgbg(AnsiValue(254), AnsiValue(160));
-        Self { hint, info, error }
+        Self { hint, info, task, error }
     }
 }
 
