@@ -18,9 +18,6 @@ impl View for TitleView {
     fn set_available_area(&mut self, area: Area) {
         self.area = area;
     }
-    fn get_area(&self) -> &Area {
-        &self.area
-    }
     fn draw(
         &mut self,
         w: &mut W,
@@ -30,7 +27,7 @@ impl View for TitleView {
         let path = state.open_closet.path().to_string_lossy();
         let md = format!(" **SafeCloset** ` ` {} ` ` {} ", &path, state_info(state));
         let composite = Composite::from_inline(&md);
-        self.go_to_line(w, 0)?;
+        self.go_to(w, self.area.left, self.area.top)?;
         let width = self.area.width as usize;
         app_skin.title
             .write_composite_fill(w, composite, width, Alignment::Unspecified)?;
