@@ -16,8 +16,6 @@ pub trait View: Default {
     /// set the outside area. This view may take it wholly or partially
     fn set_available_area(&mut self, area: Area);
 
-    fn get_area(&self) -> &Area;
-
     /// Render the view in its area
     fn draw(
         &mut self,
@@ -31,9 +29,4 @@ pub trait View: Default {
         Ok(())
     }
 
-    fn go_to_line(&self, w: &mut W, y: u16) -> Result<(), SafeClosetError> {
-        w.queue(cursor::MoveTo(self.get_area().left, y))?;
-        Ok(())
-    }
-
 }
